MCD alt
CLIENT ( Réf. client, Nom u1, Prénom u1, Adresse, Mail u2 )

- Le champ Réf. client constitue la clé primaire de la table. C'était déjà un identifiant de l'entité CLIENT.
- Les champs Nom et Prénom étaient déjà de simples attributs de l'entité CLIENT. Il obéit à la contrainte d'unicité 1.
- Le champ Adresse était déjà un simple attribut de l'entité CLIENT.
- Le champ Mail était déjà un simple attribut de l'entité CLIENT. Il obéit à la contrainte d'unicité 2.

FOO ( foo, bar u1, biz u1 u2, buz u2, qux u3, quux u1 u2 u3 )

- Le champ foo constitue la clé primaire de la table. C'était déjà un identifiant de l'entité FOO.
- Le champ bar était déjà un simple attribut de l'entité FOO. Il obéit à la contrainte d'unicité 1.
- Le champ biz était déjà un simple attribut de l'entité FOO. Il obéit aux contraintes d'unicité 1 et 2.
- Le champ buz était déjà un simple attribut de l'entité FOO. Il obéit à la contrainte d'unicité 2.
- Le champ qux était déjà un simple attribut de l'entité FOO. Il obéit à la contrainte d'unicité 3.
- Le champ quux était déjà un simple attribut de l'entité FOO. Il obéit aux contraintes d'unicité 1, 2 et 3.

UTILISER ( carnet u1, projet u2, technicien u1 u2 )

- Le champ carnet fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité UTILISER. Il obéit en outre à la contrainte d'unicité 1.
- Le champ projet fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité UTILISER. Il obéit en outre à la contrainte d'unicité 2.
- Le champ technicien était déjà un simple attribut de l'entité UTILISER. Il obéit aux contraintes d'unicité 1 et 2.